@@ -45,7 +45,12 @@ class UserAgent(object):
         except KeyError as e:
             raise error.AnoleUserAgnetError(f"Browser `{browser}` is not support.") from e
 
-    def fake(self, header: dict, browser="random"):
+    def fake(self, header=None, browser="random"):
+        header = header or {}
+
+        assert isinstance(header, dict), \
+            'header must be dict'
+
         if "user-agent" not in [key.lower() for key in header.keys()]:
             header.update({"user-agent": eval(f"self.{browser}")})
 
