@@ -15,7 +15,7 @@ from anole import setting, error
 @retry(stop_max_attempt_number=setting.HTTP_RETRY)
 def get(url):
     res = requests.get(url)
-    if res.status_code != "200":
+    if res.status_code != 200:
         raise error.AnoleCrawlError("Download cache failed, please check.")
     return res
 
